function [cal_open,cal_short,cal_match,...
    cal_s11_through,cal_s21_through,cal_s12_through,cal_s22_through]...
    = rosenberger53k34rmson3(frequency)
%ROSENBERGER Rosenberger 53K34R-MSON3 Kalibrierkit
%   wahre Reflexionsfaktoren und Streuparameter des Kalibrierkits berechnen
%   Als Through-Standard wurde ein einfacher nicht vom Kalibrierkit
%   stammender Adapter verwendet.
%   input arguments
%       frequency       Messfrequenzen
%   output arguments
%       cal_open        wahre Reflexionsfaktoren des Open-Standards
%       cal_short       wahre Reflexionsfaktoren des Short-Standards
%       cal_match       wahre Reflexionsfaktoren des Match-Standards
%       cal_s11_through wahre Streuparameter S11 des Through-Standards
%       cal_s21_through wahre Streuparameter S11 des Through-Standards
%       cal_s12_through wahre Streuparameter S11 des Through-Standards
%       cal_s22_through wahre Streuparameter S11 des Through-Standards
%
%   22.10.2019          T. Weber    

c = 2.997925e8; % Lichtgeschwindigkeit
rb = 50; % Bezugswiderstand

% Streukapazitten des Open-Standards
c0 = -13.0263e-15;
c1 = 125.153e-27;
c2 = 2947.55e-36;
c3 = -408.224e-45; 
capacity = c0+c1*frequency(:)+c2*frequency(:).^2+c3*frequency(:).^3;

% wahre Reflexionsfaktoren des Open-Standards berechnen
l_open = 11.2e-3; % Lnge des Open-Standards
cal_open = (1-j*2*pi*rb*frequency(:).*capacity)./(1+j*2*pi*rb*frequency(:).*capacity)...
    .*exp(-j*4*pi*l_open*frequency(:)/c);

% wahre Reflexionsfaktoren des Short-Standards berechnen
l_short = 11.2e-3; % Lnge des Short-Standards
cal_short = -exp(-j*4*pi*l_short*frequency(:)/c);

% wahre Reflexionsfaktoren des Match-Standards berechnen
cal_match = zeros(numel(frequency),1);

% wahre Streuparameter des Trough-Standards berechnen
l_through = 29e-3; % Lnges des Through-Standards
cal_s11_through = zeros(numel(frequency),1);
cal_s21_through = exp(-j*2*pi*l_through*frequency(:)/c);
cal_s12_through = exp(-j*2*pi*l_through*frequency(:)/c);
cal_s22_through = zeros(numel(frequency),1);

end
