function [fstart,fstop,n] = vna_parameters(obj,fstart,fstop,n)
%VNA_PARAMETERS Parameter der VNA-Messung einstellen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       fstart          gewnschte Startfrequenz
%       fstop           gewnschte Stopfrequenz
%       n               gewnschte Anzahl der Messpunkte
%   output arguments
%       fstart          tatschliche Startfrequenz
%       fstop           tatschliche Stopfrequenz
%       n               tatschliche Anzahl der Messpunkte
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%
%   SCPI-Befehle 
%       *RST
%       INSTrument[:SELect] <Application>
%       CALCulate<Ch>:PARameter:DELete '<string>'
%       CALCulate<Ch>:PARameter:DELete:CALL
%       INITiate<Ch>:CONTinuous <Boolean>
%       [SENSe<Ch>:]FREQuency:STARt <start_frequency>
%       [SENSe<Ch>:]FREQuency:STOP <stop_frequency>
%       [SENSe<Ch>:]SWEep:POINts <no_points>
%
%   28.08.2019          T. Weber    
%   29.11.2020          Untersttzung fr FPC1500 hinzugefgt

switch obj.Name
    case 'none'
        
    case {'zvl','zvb'}
        % Preset
        fprintf(obj,'*RST');
        
        % den einen vorhanden Trace lschen
        fprintf(obj,'CALC1:PAR:DEL ''Trc1''');

        % Single Sweep Mode einstellen
        fprintf(obj,'INIT1:CONT OFF');
        
        % Parameter einstellen
        fprintf(obj,'FREQ:STAR %f',fstart);
        fprintf(obj,'FREQ:STOP %f',fstop);
        fprintf(obj,'SWE:POIN %d',n);

        % tatschliche Parameter auslesen
        fprintf(obj,'FREQ:STAR?');
        fstart = fscanf(obj,'%f');
        fprintf(obj,'FREQ:STOP?');
        fstop = fscanf(obj,'%f');
        fprintf(obj,'SWE:POIN?');
        n = fscanf(obj,'%d');

    case 'znle'
        % Preset
        fprintf(obj,'*RST');
        
        % vorhande Traces lschen
        fprintf(obj,'CALC1:PAR:DEL:CALL');
        
        % Single Sweep Mode einstellen
        fprintf(obj,'INIT1:CONT OFF');
        
        % Parameter einstellen
        fprintf(obj,'FREQ:STAR %f',fstart);
        fprintf(obj,'FREQ:STOP %f',fstop);
        fprintf(obj,'SWE:POIN %d',n);

        % tatschliche Parameter auslesen
        fprintf(obj,'FREQ:STAR?');
        fstart = fscanf(obj,'%f');
        fprintf(obj,'FREQ:STOP?');
        fstop = fscanf(obj,'%f');
        fprintf(obj,'SWE:POIN?');
        n = fscanf(obj,'%d');
        
    case 'fpc'
        % Preset
        fprintf(obj,'*RST');
        
        % Vektornetzwerkanalysator aktivieren
        fprintf(obj,'INST NAN');

        % Single Sweep Mode einstellen
        fprintf(obj,'INIT:CONT OFF');

        % Parameter einstellen
        fprintf(obj,'FREQ:STAR %f',fstart);
        fprintf(obj,'FREQ:STOP %f',fstop);
        fprintf(obj,'SWE:POIN %d',n);

        % tatschliche Parameter auslesen
        fprintf(obj,'FREQ:STAR?');
        fstart = fscanf(obj,'%f');
        fprintf(obj,'FREQ:STOP?');
        fstop = fscanf(obj,'%f');
        fprintf(obj,'SWE:POIN?');
        n = fscanf(obj,'%d');
        
    otherwise
    	error('unsupported VNA');
        
end

end
